from django.apps import AppConfig


class LbHealthCheckConfig(AppConfig):
    name = "lb_health_check"
